#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-rename-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-rename-plugin-2.3.0.0-2tRaljXaVu37z1OR9CIaNi
key:                  hls-rename-plugin-2.3.0.0-2tRaljXaVu37z1OR9CIaNi
license:              Apache-2.0
maintainer:           madine.oliver@gmail.com
author:               Oliver Madine
synopsis:             Rename plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  22feff4c6f259c7cd72252e4b52548b4
exposed:              True
exposed-modules:      Ide.Plugin.Rename
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-rename-plugin
hs-libraries:         HShls-rename-plugin-2.3.0.0-2tRaljXaVu37z1OR9CIaNi
depends:
    base-4.18.2.1 containers-0.6.7 extra-1.7.16-1gq06OiTdkG7AFSCXWttYR
    ghc-9.6.6 ghc-exactprint-1.7.1.0-JTh6MSrFKx8KvNvrzGFeFv
    ghcide-2.3.0.0-Ik0ryRnzAkjLLtdRv2NXeJ
    hashable-1.4.7.0-ISMWzeTPqg7GxJZ08wJoa
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-CpGQiEnMvnzDTgQq628ZrL
    hls-plugin-api-2.3.0.0-8Co8J5z09Yj7X5mYCRuc6W
    hls-refactor-plugin-2.3.0.0-Dj1jBcodXdE8WJwfEDYMvz
    lens-5.3.4-6xqoTm4kiuC8ULAJ3RTBph
    lsp-2.2.0.0-G42MvkI8UUDFwGwofUskp3
    lsp-types-2.0.2.0-LmHG0NjoDNe4jC9nPopLX6
    mod-0.2.1.0-CfeniRWTBv61zHLuaI1osJ mtl-2.3.1
    syb-0.7.3-AsxB5kY1s6JBFiF2Kn9gZL text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-6k45pUyQa13JRvzUHn0wS1

haddock-interfaces:
    /usr/share/doc/haskell-hls-rename-plugin/html/hls-rename-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-rename-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

